#ifndef ARRAY_COL_READER_HPP
#define ARRAY_COL_READER_HPP

#include <Python.h>

#include "parser_defs.hpp"

extern PyTypeObject ArrayColReaderType;

#endif // #ifndef ARRAY_COL_READER_HPP



